@@ -104,7 +104,6 @@ struct _HTMLTokenizerPrivate {
 		TabPending
 	} pending;
 
-
 	gchar searchBuffer[20];
 	gint searchCount;
 	gint searchGtkHTMLCount;
@@ -117,17 +116,15 @@ struct _HTMLTokenizerPrivate {
 	GList *blocking; /* Blocking tokens */
 
 	const gchar *searchFor;
-	
+
 	gboolean enableconvert;
-	
+
 	gchar * content_type;
 	/*convert*/
 	GIConv iconv_cd;
 
 };
 
-
-
 static const gchar *commentStart = "<!--";
 static const gchar *scriptEnd = "</script>";
 static const gchar *styleEnd = "</style>";
@@ -153,17 +150,16 @@ static void     html_tokenizer_finalize             (GObject *);
 static void     html_tokenizer_real_change          (HTMLTokenizer *, const gchar *content_type);
 static void     html_tokenizer_real_begin           (HTMLTokenizer *, const gchar *content_type);
 static void     html_tokenizer_real_engine_type (HTMLTokenizer *t, gboolean engine_type);
-static void     html_tokenizer_real_write           (HTMLTokenizer *, const gchar *str, size_t size);
+static void     html_tokenizer_real_write           (HTMLTokenizer *, const gchar *str, gsize size);
 static void     html_tokenizer_real_end             (HTMLTokenizer *);
 static const gchar *
-				html_tokenizer_real_get_content_type(HTMLTokenizer *);
+				html_tokenizer_real_get_content_type (HTMLTokenizer *);
 static gboolean
-				html_tokenizer_real_get_engine_type(HTMLTokenizer *);
+				html_tokenizer_real_get_engine_type (HTMLTokenizer *);
 static gchar   *html_tokenizer_real_peek_token      (HTMLTokenizer *);
 static gchar   *html_tokenizer_real_next_token      (HTMLTokenizer *);
 static gboolean html_tokenizer_real_has_more_tokens (HTMLTokenizer *);
-static gchar   *html_tokenizer_converted_token (HTMLTokenizer *t,const gchar* token);
-
+static gchar   *html_tokenizer_converted_token (HTMLTokenizer *t,const gchar * token);
 
 static HTMLTokenizer *html_tokenizer_real_clone     (HTMLTokenizer *);
 
@@ -174,11 +170,11 @@ static void               html_tokenizer_blocking_push       (HTMLTokenizer  *t,
 							      HTMLTokenType   tt);
 static void               html_tokenizer_tokenize_one_char   (HTMLTokenizer  *t,
 							      const gchar  **src);
-static void				  add_char(HTMLTokenizer *t, gchar c);
+static void				  add_char (HTMLTokenizer *t, gchar c);
 
-gboolean 				  is_need_convert(const gchar* token);
+gboolean				  is_need_convert (const gchar * token);
 
-gchar*					  html_tokenizer_convert_entity(gchar * token);
+gchar *					  html_tokenizer_convert_entity (gchar * token);
 
 static GObjectClass *parent_class = NULL;
 
@@ -219,7 +215,7 @@ html_tokenizer_class_init (HTMLTokenizerClass *klass)
 			      G_TYPE_NONE,
 			      1, G_TYPE_POINTER);
 
-	html_tokenizer_signals [HTML_TOKENIZER_END_SIGNAL] =
+	html_tokenizer_signals[HTML_TOKENIZER_END_SIGNAL] =
 		g_signal_new ("end",
 			      G_TYPE_FROM_CLASS (klass),
 			      G_SIGNAL_RUN_LAST,
@@ -289,10 +285,10 @@ html_tokenizer_init (HTMLTokenizer *t)
 	p->blocking = NULL;
 
 	p->searchFor = NULL;
-	
+
 	/* Use old logic and not convert charset */
 	p->enableconvert = FALSE;
-	
+
 	p->content_type = g_strdup ("html/text; charset=utf-8");
 }
 
@@ -300,15 +296,15 @@ static void
 html_tokenizer_finalize (GObject *obj)
 {
 	HTMLTokenizer *t = HTML_TOKENIZER (obj);
-	
+
 	html_tokenizer_reset (t);
-	
-	if(is_valid_g_iconv (t->priv->iconv_cd))
+
+	if (is_valid_g_iconv (t->priv->iconv_cd))
 		g_iconv_close (t->priv->iconv_cd);
-		
-	if(t->priv->content_type)
-		g_free(t->priv->content_type);
-		
+
+	if (t->priv->content_type)
+		g_free (t->priv->content_type);
+
 	g_free (t->priv);
 	t->priv = NULL;
 
@@ -369,8 +365,8 @@ html_token_buffer_append_token (HTMLTokenBuffer * buf, const gchar *token, gint
 	/* copy token and terminate with zero */
 	strncpy (buf->data + buf->used, token, len);
 	buf->used += len;
-	buf->data [buf->used] = 0;
-	buf->used ++;
+	buf->data[buf->used] = 0;
+	buf->used++;
 
 	dt(printf ("html_token_buffer_append_token: '%s'\n", buf->data + buf->used - 1 - len));
 
@@ -419,7 +415,7 @@ html_tokenizer_real_peek_token (HTMLTokenizer *t)
 		/* finally get first token */
 		token = buffer->data;
 	}
-	
+
 	return html_tokenizer_converted_token (t,token);
 }
 
@@ -432,9 +428,9 @@ is_valid_g_iconv (const GIConv iconv_cd)
 
 /*Convert only chars when code >127*/
 gboolean
-is_need_convert (const gchar* token)
+is_need_convert (const gchar * token)
 {
-	int i=strlen (token);
+	gint i=strlen (token);
 	for (;i>=0;i--)
 		if (token[i]&128)
 			return TRUE;
@@ -459,7 +455,7 @@ html_tokenizer_convert_entity (gchar *token)
 	write_pos = resulted;
 	read_pos = token;
 	while (read_pos < full_pos) {
-		size_t count_chars = strcspn (read_pos, "&");
+		gsize count_chars = strcspn (read_pos, "&");
 		memcpy (write_pos, read_pos, count_chars);
 		write_pos += count_chars;
 		read_pos += count_chars;
@@ -469,7 +465,7 @@ html_tokenizer_convert_entity (gchar *token)
 				/*value to add*/
 				gunichar value = INVALID_ENTITY_CHARACTER_MARKER;
 				/*skip not needed &*/
-				read_pos ++;
+				read_pos++;
 				count_chars = strcspn (read_pos, ";");
 				if (count_chars < 14 && count_chars > 1) {
 					/*save for recovery*/
@@ -487,14 +483,14 @@ html_tokenizer_convert_entity (gchar *token)
 					} else {
 						value = html_entity_parse (read_pos, strlen (read_pos));
 					}
-					if(value != INVALID_ENTITY_CHARACTER_MARKER){							
+					if (*read_pos == '#' || value != INVALID_ENTITY_CHARACTER_MARKER) {
 						write_pos += g_unichar_to_utf8 (value, write_pos);
 						read_pos += (count_chars + 1);
 					} else {
 						/*recovery old value - it's not entity*/
 						write_pos += g_unichar_to_utf8 ('&', write_pos);
 						*(read_pos + count_chars) = save_gchar;
-					}					
+					}
 				}
 				else
 					/*very large string*/
@@ -512,12 +508,12 @@ gchar *
 convert_text_encoding (const GIConv iconv_cd,
                        const gchar *token)
 {
-	size_t currlength;
+	gsize currlength;
 	gchar *newbuffer;
 	gchar *returnbuffer;
 	const gchar *current;
-	size_t newlength;
-	size_t oldlength;
+	gsize newlength;
+	gsize oldlength;
 
 	if (token == NULL)
 		return NULL;
@@ -536,10 +532,10 @@ convert_text_encoding (const GIConv iconv_cd,
 			if (currlength > 0) {
 				g_warning ("IconvError=%s", current);
 				*newbuffer = INVALID_ENTITY_CHARACTER_MARKER;
-				newbuffer ++;
-				current ++;
-				currlength --;
-				newlength --;
+				newbuffer++;
+				current++;
+				currlength--;
+				newlength--;
 			}
 		}
 		returnbuffer[oldlength - newlength] = '\0';
@@ -551,7 +547,7 @@ convert_text_encoding (const GIConv iconv_cd,
 
 static gchar *
 html_tokenizer_converted_token (HTMLTokenizer *t,
-                                const gchar* token)
+                                const gchar * token)
 {
 	if (token != NULL) {
 		struct _HTMLTokenizerPrivate *p = t->priv;
@@ -618,7 +614,7 @@ html_tokenizer_real_next_token (HTMLTokenizer *t)
 
 	p->tokens_num--;
 	g_assert (p->tokens_num >= 0);
-	
+
 	return html_tokenizer_converted_token (t, token);
 }
 
@@ -679,44 +675,44 @@ is_text (const gchar *content_type)
 	return content_type && strstr (content_type, "text/") != NULL;
 }
 
-static const gchar*
-get_encoding_from_content_type(const gchar * content_type)
+static const gchar *
+get_encoding_from_content_type (const gchar * content_type)
 {
 	gchar * charset;
-	if(content_type)
+	if (content_type)
 	{
 		charset =  g_strrstr (content_type, "charset=");
-		if(charset != NULL)
+		if (charset != NULL)
 			return charset + strlen ("charset=");
 		charset =  g_strrstr (content_type, "encoding=");
-		if(charset != NULL)
+		if (charset != NULL)
 			return charset + strlen ("encoding=");
-		
+
 	}
 	return NULL;
 }
 
 GIConv
-generate_iconv_from(const gchar * content_type)
+generate_iconv_from (const gchar * content_type)
 {
-	if(content_type)
-		if(!charset_is_utf8(content_type))
+	if (content_type)
+		if (!charset_is_utf8 (content_type))
 		{
 			const gchar * encoding = get_encoding_from_content_type (content_type);
-			if(encoding)
+			if (encoding)
 				return g_iconv_open ("utf-8", encoding);
 		}
 	return NULL;
 }
 
 GIConv
-generate_iconv_to(const gchar * content_type)
+generate_iconv_to (const gchar * content_type)
 {
-	if(content_type)
-		if(!charset_is_utf8 (content_type))
+	if (content_type)
+		if (!charset_is_utf8 (content_type))
 		{
 			const gchar * encoding = get_encoding_from_content_type (content_type);
-			if(encoding)
+			if (encoding)
 				return g_iconv_open (encoding, "utf-8");
 		}
 	return NULL;
@@ -727,32 +723,32 @@ html_tokenizer_real_engine_type (HTMLTokenizer *t, gboolean engine_type)
 {
 	struct _HTMLTokenizerPrivate *p;
 	p = t->priv;
-	
+
 	p->enableconvert = engine_type;
 }
 
 static void
 html_tokenizer_real_change (HTMLTokenizer *t, const gchar *content_type)
-{	
+{
 	struct _HTMLTokenizerPrivate *p;
-	if(!is_text (content_type))
+	if (!is_text (content_type))
 		return;
-			
+
 	p = t->priv;
-	
+
 	if (!p->enableconvert)
 		return;
-	
-	if(p->content_type)
-		g_free(p->content_type);
-	
+
+	if (p->content_type)
+		g_free (p->content_type);
+
 	p->content_type = g_ascii_strdown ( content_type, -1);
-	
-	if(is_valid_g_iconv (p->iconv_cd))
+
+	if (is_valid_g_iconv (p->iconv_cd))
 		g_iconv_close (p->iconv_cd);
-		
+
 	p->iconv_cd = generate_iconv_from (p->content_type);
-	
+
 #if 0
 	if (charset_is_utf8 (p->content_type))
 		g_warning ("Trying UTF-8");
@@ -761,7 +757,6 @@ html_tokenizer_real_change (HTMLTokenizer *t, const gchar *content_type)
 #endif
 }
 
-
 static void
 html_tokenizer_real_begin (HTMLTokenizer *t, const gchar *content_type)
 {
@@ -848,19 +843,21 @@ html_tokenizer_append_token (HTMLTokenizer *t, const gchar *string, gint len)
 	}
 }
 
-static void add_byte (HTMLTokenizer *t, const gchar **c)
+static void
+add_byte (HTMLTokenizer *t, const gchar **c)
 {
 	add_char (t,**c);
 	(*c) ++;
 }
 
 static void
-add_char(HTMLTokenizer *t, gchar c){
+add_char (HTMLTokenizer *t, gchar c)
+{
 	struct _HTMLTokenizerPrivate *p = t->priv;
-	if(c!='\0')
+	if (c!='\0')
 	{
 		*(p->dest) = c;
-		p->dest ++;
+		p->dest++;
 		*(p->dest) = 0;
 	}
 }
@@ -953,12 +950,12 @@ in_comment (HTMLTokenizer *t, const gchar **src)
 {
 	struct _HTMLTokenizerPrivate *p = t->priv;
 
-	if (**src == '-') {	             /* Look for "-->" */
+	if (**src == '-') {		     /* Look for "-->" */
 		if (p->searchCount < 2)
 			p->searchCount++;
 	} else if (p->searchCount == 2 && (**src == '>')) {
 		p->comment = FALSE;          /* We've got a "-->" sequence */
-	} else if (tolower (**src) == gtkhtmlStart [p->searchGtkHTMLCount]) {
+	} else if (tolower (**src) == gtkhtmlStart[p->searchGtkHTMLCount]) {
 		if (p->searchGtkHTMLCount == 8) {
 			p->extension    = TRUE;
 			p->comment = FALSE;
@@ -966,7 +963,7 @@ in_comment (HTMLTokenizer *t, const gchar **src)
 			p->searchExtensionEndCount = 0;
 			p->searchGtkHTMLCount = 0;
 		} else
-			p->searchGtkHTMLCount ++;
+			p->searchGtkHTMLCount++;
 	} else {
 		p->searchGtkHTMLCount = 0;
 		if (p->searchCount < 2)
@@ -994,7 +991,7 @@ in_extension (HTMLTokenizer *t, const gchar **src)
 	/* check for "-->" */
 	if (!p->tquote && **src == '-') {
 		if (p->searchExtensionEndCount < 2)
-			p->searchExtensionEndCount ++;
+			p->searchExtensionEndCount++;
 		(*src) ++;
 	} else if (!p->tquote && p->searchExtensionEndCount == 2 && **src == '>') {
 		p->extension = FALSE;
@@ -1006,7 +1003,7 @@ in_extension (HTMLTokenizer *t, const gchar **src)
 
 				while (p->searchExtensionEndCount) {
 					extension_one_char (t, &c);
-					p->searchExtensionEndCount --;
+					p->searchExtensionEndCount--;
 				}
 			}
 		}
@@ -1023,10 +1020,10 @@ in_script_or_style (HTMLTokenizer *t, const gchar **src)
 	if (p->scriptCodeSize + 11 > p->scriptCodeMaxSize)
 		p->scriptCode = g_realloc (p->scriptCode, p->scriptCodeMaxSize += 1024);
 
-	if ((**src == '>' ) && ( p->searchFor [p->searchCount] == '>')) {
+	if ((**src == '>' ) && ( p->searchFor[p->searchCount] == '>')) {
 		(*src)++;
-		p->scriptCode [p->scriptCodeSize] = 0;
-		p->scriptCode [p->scriptCodeSize + 1] = 0;
+		p->scriptCode[p->scriptCodeSize] = 0;
+		p->scriptCode[p->scriptCodeSize + 1] = 0;
 		if (p->script) {
 			p->script = FALSE;
 		}
@@ -1039,12 +1036,12 @@ in_script_or_style (HTMLTokenizer *t, const gchar **src)
 	/* Check if a </script> tag is on its way */
 	else if (p->searchCount > 0) {
 		gboolean put_to_script = FALSE;
-		if (tolower (**src) == p->searchFor [p->searchCount]) {
-			p->searchBuffer [p->searchCount] = **src;
+		if (tolower (**src) == p->searchFor[p->searchCount]) {
+			p->searchBuffer[p->searchCount] = **src;
 			p->searchCount++;
 			(*src)++;
 		}
-		else if (p->searchFor [p->searchCount] == '>') {
+		else if (p->searchFor[p->searchCount] == '>') {
 			/* There can be any number of white-space characters between
 			   tag name and closing '>' so try to move through them, if possible */
 
@@ -1052,33 +1049,32 @@ in_script_or_style (HTMLTokenizer *t, const gchar **src)
 			while (isspace (**p))
 				(*p)++;
 
-			
 			if (**p == '>')
 				*src = *p;
 			else
 				put_to_script = TRUE;
 		}
-		else 
+		else
 			put_to_script = TRUE;
 
 		if (put_to_script) {
 			gchar *c;
 
-			p->searchBuffer [p->searchCount] = 0;
+			p->searchBuffer[p->searchCount] = 0;
 			c = p->searchBuffer;
 			while (*c)
-				p->scriptCode [p->scriptCodeSize++] = *c++;
-			p->scriptCode [p->scriptCodeSize] = **src; (*src)++;
+				p->scriptCode[p->scriptCodeSize++] = *c++;
+			p->scriptCode[p->scriptCodeSize] = **src; (*src)++;
 			p->searchCount = 0;
 		}
 	}
 	else if (**src == '<') {
 		p->searchCount = 1;
-		p->searchBuffer [0] = '<';
+		p->searchBuffer[0] = '<';
 		(*src)++;
 	}
 	else {
-		p->scriptCode [p->scriptCodeSize] = **src;
+		p->scriptCode[p->scriptCodeSize] = **src;
 		(*src)++;
 	}
 }
@@ -1147,7 +1143,7 @@ end_tag (HTMLTokenizer *t, const gchar **src)
 	/* Make the tag lower case */
 	ptr = p->buffer + 2;
 	if (p->pre || *ptr == '/') {
-	    	/* End tag */
+		/* End tag */
 		p->discard = NoneDiscard;
 	}
 	else {
@@ -1266,8 +1262,6 @@ in_crlf (HTMLTokenizer *t, const gchar **src)
 static void
 in_space_or_tab (HTMLTokenizer *t, const gchar **src)
 {
-	gchar *ptr;
-
 	if (t->priv->tquote) {
 		if (t->priv->discard == NoneDiscard)
 			t->priv->pending = SpacePending;
@@ -1276,7 +1270,6 @@ in_space_or_tab (HTMLTokenizer *t, const gchar **src)
 		t->priv->searchCount = 0; /* Stop looking for <!-- sequence */
 		if (t->priv->discard == NoneDiscard)
 			t->priv->pending = SpacePending;
-		ptr = t->priv->buffer;
 	}
 	else if (t->priv->pre || t->priv->textarea) {
 		if (t->priv->pending)
@@ -1421,10 +1414,10 @@ html_tokenizer_tokenize_one_char (HTMLTokenizer *t, const gchar **src)
 }
 
 static void
-html_tokenizer_real_write (HTMLTokenizer *t, const gchar *string, size_t size)
+html_tokenizer_real_write (HTMLTokenizer *t, const gchar *string, gsize size)
 {
 	const gchar *src = string;
-	
+
 	while ((src - string) < size)
 		html_tokenizer_tokenize_one_char (t, &src);
 }
@@ -1472,10 +1465,10 @@ html_tokenizer_blocking_pop (HTMLTokenizer *t)
 void
 html_tokenizer_begin (HTMLTokenizer *t, const gchar *content_type)
 {
-	
+
 	g_return_if_fail (t && HTML_IS_TOKENIZER (t));
 
-	g_signal_emit (t, html_tokenizer_signals [HTML_TOKENIZER_BEGIN_SIGNAL], 0, content_type);
+	g_signal_emit (t, html_tokenizer_signals[HTML_TOKENIZER_BEGIN_SIGNAL], 0, content_type);
 }
 
 void
@@ -1483,18 +1476,17 @@ html_tokenizer_set_engine_type (HTMLTokenizer *t, gboolean engine_type)
 {
 	g_return_if_fail (t && HTML_IS_TOKENIZER (t));
 
-	g_signal_emit (t, html_tokenizer_signals [HTML_TOKENIZER_CHANGEENGINE_SIGNAL], 0, engine_type);
+	g_signal_emit (t, html_tokenizer_signals[HTML_TOKENIZER_CHANGEENGINE_SIGNAL], 0, engine_type);
 }
 
 void
 html_tokenizer_change_content_type (HTMLTokenizer *t,const gchar *content_type)
-{	
+{
 	g_return_if_fail (t && HTML_IS_TOKENIZER (t));
 
-	g_signal_emit (t, html_tokenizer_signals [HTML_TOKENIZER_CHANGECONTENT_SIGNAL], 0, content_type);
+	g_signal_emit (t, html_tokenizer_signals[HTML_TOKENIZER_CHANGECONTENT_SIGNAL], 0, content_type);
 }
 
-
 void
 html_tokenizer_end (HTMLTokenizer *t)
 {
@@ -1504,7 +1496,7 @@ html_tokenizer_end (HTMLTokenizer *t)
 }
 
 void
-html_tokenizer_write (HTMLTokenizer *t, const gchar *str, size_t size)
+html_tokenizer_write (HTMLTokenizer *t, const gchar *str, gsize size)
 {
 	HTMLTokenizerClass *klass;
 
@@ -1535,23 +1527,23 @@ html_tokenizer_peek_token (HTMLTokenizer *t)
 }
 
 const gchar *
-html_tokenizer_get_content_type(HTMLTokenizer *t)
+html_tokenizer_get_content_type (HTMLTokenizer *t)
 {
 	HTMLTokenizerClass *klass;
 
 	g_return_val_if_fail (t && HTML_IS_TOKENIZER (t), NULL);
 
 	klass = HTML_TOKENIZER_CLASS (G_OBJECT_GET_CLASS (t));
-		
-	if(klass->get_content_type)
-		return  klass->get_content_type(t);
+
+	if (klass->get_content_type)
+		return  klass->get_content_type (t);
 
 	g_warning ("No get_content_type method defined.");
 	return NULL;
 
 }
 
-gboolean       
+gboolean
 html_tokenizer_get_engine_type (HTMLTokenizer *t)
 {
 	HTMLTokenizerClass *klass;
@@ -1559,9 +1551,9 @@ html_tokenizer_get_engine_type (HTMLTokenizer *t)
 	g_return_val_if_fail (t && HTML_IS_TOKENIZER (t),FALSE);
 
 	klass = HTML_TOKENIZER_CLASS (G_OBJECT_GET_CLASS (t));
-		
-	if(klass->get_engine_type)
-		return  klass->get_engine_type(t);
+
+	if (klass->get_engine_type)
+		return  klass->get_engine_type (t);
 
 	g_warning ("No get_engine_type method defined.");
 	return FALSE;
